pub struct LibraryState { /* private fields */ }Expand description
The library state store.
Implementations
Sourceimpl LibraryState
impl LibraryState
Sourcepub fn new() -> (Self, UnboundedReceiver<LibraryFull>)
pub fn new() -> (Self, UnboundedReceiver<LibraryFull>)
create a new library state store, and return the receiver for listening to state updates.
Sourcepub async fn main_loop(
&self,
daemon: Arc<MusicPlayerClient>,
action_rx: UnboundedReceiver<LibraryAction>,
interrupt_rx: Receiver<Interrupted>,
) -> Result<Interrupted>
pub async fn main_loop( &self, daemon: Arc<MusicPlayerClient>, action_rx: UnboundedReceiver<LibraryAction>, interrupt_rx: Receiver<Interrupted>, ) -> Result<Interrupted>
a loop that updates the library state every tick.
Errors
Fails if the state cannot be sent or if the daemon client can’t connect to the server or if the daemon returns an error