Dispatcher

Struct Dispatcher 

pub struct Dispatcher { /* private fields */ }
an all-in-one dispactcher for managing state updates.

Implementations

Source

impl Dispatcher

pub fn new() -> (Self, Receivers)

pub async fn main_loop( &self, daemon: MusicPlayerClient, terminator: Terminator, action_rx: UnboundedReceiver<Action>, interrupt_rx: Receiver<Interrupted>, ) -> Result<Interrupted>

the main loop for the dispatcher.

the dispatcher will run until the user exits the application.

Errors

if any of the state stores fail to run.