pub struct Subscriber;Implementations
Sourceimpl Subscriber
impl Subscriber
Sourcepub async fn main_loop(
&self,
daemon: Arc<MusicPlayerClient>,
action_tx: UnboundedSender<Action>,
interrupt_rx: Receiver<Interrupted>,
) -> Result<Interrupted>
pub async fn main_loop( &self, daemon: Arc<MusicPlayerClient>, action_tx: UnboundedSender<Action>, interrupt_rx: Receiver<Interrupted>, ) -> Result<Interrupted>
Main loop for the subscriber.
Errors
Returns an error if the main loop cannot be started, or if an error occurs while handling a message.
Sourcepub fn handle_message(
&self,
action_tx: &UnboundedSender<Action>,
message: Message,
) -> Result<()>
pub fn handle_message( &self, action_tx: &UnboundedSender<Action>, message: Message, ) -> Result<()>
Handle a message received from the UDP socket.
Errors
Returns an error if the message cannot be handled.