Module ui

This module contains the implementations of the TUI.

The app is responsible for rendering the state of the application to the terminal.

The app is updated every tick, and they use the state stores to get the latest state.

Modules

app
Handles the main application view logic and state.
colors
components
widgets

Structs

AppState
UiManager

Functions

init_panic_hook