Module components

Module components 

Modules

content_view
The content view displays the contents of the current view (e.g. the songs in a playlist, the search results, etc.).
control_panel
The control panel is a fixed height panel at the bottom of the screen that:
queuebar
Implementation of the Queue Bar component, a scrollable list of the songs in the queue.
sidebar
Implement the sidebar component.

Structs

RenderProps

Traits

Component
ComponentRender