pub enum ActiveView {
}Variants
None
Blank view.
Search
A view with a search bar and search results.
Songs
A view with all the songs in the users library.
Song(Ulid)
A view of a specific song.
Albums
A view with all the albums in the users library.
Album(Ulid)
A view of a specific album.
Artists
A view with all the artists in the users library.
Artist(Ulid)
A view of a specific artist.
Playlists
A view with all the playlists in the users library.
Playlist(Ulid)
A view of a specific playlist.
DynamicPlaylists
A view of all the dynamic playlists in the users library.
DynamicPlaylist(Ulid)
A view of a specific dynamic playlist.
Collections
A view with all the collections in the users library.
Collection(Ulid)
A view of a specific collection.
Radio(Vec<RecordId>)
A view of a radio
Random
A view for getting a random song, album, etc.