pub struct SortableItemView<Props, Mode, Item> {
pub item_view: ItemView<Props>,
pub sort_mode: Mode,
/* private fields */
}Expand description
Wraps an ItemView with sorting functionality
Defines additional key handling for changing sort modes,
Overrides rendering since we need to display the current sort mode in the border
Fields
item_view: ItemView<Props>sort_mode: ModeTrait Implementations
Sourceimpl<Props, Mode, Item> Component for SortableItemView<Props, Mode, Item>
impl<Props, Mode, Item> Component for SortableItemView<Props, Mode, Item>
fn new(state: &AppState, action_tx: UnboundedSender<Action>) -> Selfwhere
Self: Sized,
fn move_with_state(self, state: &AppState) -> Selfwhere
Self: Sized,
fn name(&self) -> &str
fn handle_key_event(&mut self, key: KeyEvent)
fn handle_mouse_event(&mut self, mouse: MouseEvent, area: Rect)
Sourceimpl<Props, Mode, Item> ComponentRender<RenderProps> for SortableItemView<Props, Mode, Item>
impl<Props, Mode, Item> ComponentRender<RenderProps> for SortableItemView<Props, Mode, Item>
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.