pub struct AlbumViewProps {
pub id: RecordId,
pub album: Album,
pub artists: Vec<ArtistBrief>,
pub songs: Vec<SongBrief>,
}Fields
id: RecordIdalbum: Albumartists: Vec<ArtistBrief>songs: Vec<SongBrief>Trait Implementations
Sourceimpl Clone for AlbumViewProps
impl Clone for AlbumViewProps
Sourcefn clone(&self) -> AlbumViewProps
fn clone(&self) -> AlbumViewProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlbumViewProps
impl Debug for AlbumViewProps
Sourceimpl ItemViewProps for AlbumViewProps
impl ItemViewProps for AlbumViewProps
Sourcefn retrieve(view_data: &ViewData) -> Option<Self>
fn retrieve(view_data: &ViewData) -> Option<Self>
Retrieve this view’s props from the view data
fn name() -> &'static strwhere
Self: Sized,
Sourcefn none_checked_string() -> &'static strwhere
Self: Sized,
fn none_checked_string() -> &'static strwhere
Self: Sized,
The string for when no items are checked
fn info_widget(&self) -> impl Widget
Sourcefn tree_items(&self) -> Result<Vec<CheckTreeItem<'_, String>>, Error>
fn tree_items(&self) -> Result<Vec<CheckTreeItem<'_, String>>, Error>
Create the tree items for the view Read more
fn split_area(area: Rect) -> [Rect; 2]
Sourcefn handle_extra_key_events(
&mut self,
_: KeyEvent,
_: UnboundedSender<Action>,
_: &mut CheckTreeState<String>,
)
fn handle_extra_key_events( &mut self, _: KeyEvent, _: UnboundedSender<Action>, _: &mut CheckTreeState<String>, )
Handle any extra key events specific to this view
Optionally define an additional footer to give instructions for the extra key events
Sourceimpl PartialEq for AlbumViewProps
impl PartialEq for AlbumViewProps
impl Eq for AlbumViewProps
impl StructuralPartialEq for AlbumViewProps