pub struct CollectionViewProps {
pub id: RecordId,
pub collection: Collection,
pub songs: Vec<SongBrief>,
}Fields
id: RecordIdcollection: Collectionsongs: Vec<SongBrief>Trait Implementations
Sourceimpl Clone for CollectionViewProps
impl Clone for CollectionViewProps
Sourcefn clone(&self) -> CollectionViewProps
fn clone(&self) -> CollectionViewProps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollectionViewProps
impl Debug for CollectionViewProps
Sourceimpl ItemViewProps for CollectionViewProps
impl ItemViewProps for CollectionViewProps
Sourcefn retrieve(view_data: &ViewData) -> Option<Self>
fn retrieve(view_data: &ViewData) -> Option<Self>
Retrieve this view’s props from the view data
fn name() -> &'static strwhere
Self: Sized,
Sourcefn none_checked_string() -> &'static strwhere
Self: Sized,
fn none_checked_string() -> &'static strwhere
Self: Sized,
The string for when no items are checked
fn info_widget(&self) -> impl Widget
Sourcefn tree_items(&self) -> Result<Vec<CheckTreeItem<'_, String>>, Error>
fn tree_items(&self) -> Result<Vec<CheckTreeItem<'_, String>>, Error>
Create the tree items for the view Read more
Optionally define an additional footer to give instructions for the extra key events
Sourcefn scrollbar() -> Option<Scrollbar<'static>>where
Self: Sized,
fn scrollbar() -> Option<Scrollbar<'static>>where
Self: Sized,
Optionally use a scrollbar when rendering the tree
fn split_area(area: Rect) -> [Rect; 2]
Sourcefn handle_extra_key_events(
&mut self,
_: KeyEvent,
_: UnboundedSender<Action>,
_: &mut CheckTreeState<String>,
)
fn handle_extra_key_events( &mut self, _: KeyEvent, _: UnboundedSender<Action>, _: &mut CheckTreeState<String>, )
Handle any extra key events specific to this view
Sourceimpl PartialEq for CollectionViewProps
impl PartialEq for CollectionViewProps
Sourceimpl SortableViewProps<SongBrief> for CollectionViewProps
impl SortableViewProps<SongBrief> for CollectionViewProps
Sourcefn sort_items(&mut self, sort_mode: &impl SortMode<SongBrief>)
fn sort_items(&mut self, sort_mode: &impl SortMode<SongBrief>)
This exists essentially because the generic
SortableItemView doesn’t actually know what its items are, per seimpl Eq for CollectionViewProps
impl StructuralPartialEq for CollectionViewProps