pub struct RenderProps {
pub area: Rect,
pub is_focused: bool,
}Fields
area: Rectis_focused: boolTrait Implementations
Sourceimpl Clone for RenderProps
impl Clone for RenderProps
Sourcefn clone(&self) -> RenderProps
fn clone(&self) -> RenderProps
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComponentRender<RenderProps> for CollectionView
impl ComponentRender<RenderProps> for CollectionView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for ContentView
impl ComponentRender<RenderProps> for ContentView
Sourcefn render_border(&self, _: &mut Frame<'_>, props: RenderProps) -> RenderProps
fn render_border(&self, _: &mut Frame<'_>, props: RenderProps) -> RenderProps
we defer all border rendering to the active view
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for ControlPanel
impl ComponentRender<RenderProps> for ControlPanel
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for DynamicView
impl ComponentRender<RenderProps> for DynamicView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl<Props> ComponentRender<RenderProps> for ItemView<Props>where
Props: ItemViewProps,
impl<Props> ComponentRender<RenderProps> for ItemView<Props>where
Props: ItemViewProps,
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for LibraryAlbumsView
impl ComponentRender<RenderProps> for LibraryAlbumsView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for LibraryArtistsView
impl ComponentRender<RenderProps> for LibraryArtistsView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for LibraryCollectionsView
impl ComponentRender<RenderProps> for LibraryCollectionsView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for LibraryDynamicView
impl ComponentRender<RenderProps> for LibraryDynamicView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for LibraryPlaylistsView
impl ComponentRender<RenderProps> for LibraryPlaylistsView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for LibrarySongsView
impl ComponentRender<RenderProps> for LibrarySongsView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for NoneView
impl ComponentRender<RenderProps> for NoneView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for PlaylistView
impl ComponentRender<RenderProps> for PlaylistView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for QueueBar
impl ComponentRender<RenderProps> for QueueBar
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for RadioView
impl ComponentRender<RenderProps> for RadioView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for RandomView
impl ComponentRender<RenderProps> for RandomView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for SearchView
impl ComponentRender<RenderProps> for SearchView
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl ComponentRender<RenderProps> for Sidebar
impl ComponentRender<RenderProps> for Sidebar
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps,
) -> RenderProps
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps, ) -> RenderProps
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps)
Render the view’s content.
Sourceimpl Debug for RenderProps
impl Debug for RenderProps
impl Copy for RenderProps