pub struct RenderProps<'a> {
pub border: Block<'a>,
pub area: Rect,
pub text_color: Color,
pub show_cursor: bool,
}Fields
border: Block<'a>area: Recttext_color: Colorshow_cursor: boolTrait Implementations
Sourceimpl<'a> Clone for RenderProps<'a>
impl<'a> Clone for RenderProps<'a>
Sourcefn clone(&self) -> RenderProps<'a>
fn clone(&self) -> RenderProps<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> ComponentRender<RenderProps<'a>> for InputBox
impl<'a> ComponentRender<RenderProps<'a>> for InputBox
Sourcefn render_border(
&self,
frame: &mut Frame<'_>,
props: RenderProps<'a>,
) -> RenderProps<'a>
fn render_border( &self, frame: &mut Frame<'_>, props: RenderProps<'a>, ) -> RenderProps<'a>
Render the border of the view, and return the props updated with the remaining area for the view.
Sourcefn render_content(&self, frame: &mut Frame<'_>, props: RenderProps<'a>)
fn render_content(&self, frame: &mut Frame<'_>, props: RenderProps<'a>)
Render the view’s content.