pub struct CheckTreeItem<'text, Identifier> { /* private fields */ }Expand description
One item inside a CheckTree.
Can have zero or more children.
Identifier
The generic argument Identifier is used to keep the state like the currently selected or opened CheckTreeItems in the CheckTreeState.
It needs to be unique among its siblings but can be used again on parent or child CheckTreeItems.
A common example would be a filename which has to be unique in its directory while it can exist in another.
The text can be different from its identifier.
To repeat the filename analogy: File browsers sometimes hide file extensions.
The filename main.rs is the identifier while its shown as main.
Two files main.rs and main.toml can exist in the same directory and can both be displayed as main but their identifier is different.
Just like every file in a file system can be uniquely identified with its file and directory names each CheckTreeItem in a CheckTree can be with these identifiers.
As an example the following two identifiers describe the main file in a Rust cargo project: vec!["src", "main.rs"].
Implementations
Sourceimpl<'items> CheckTreeItem<'items, String>
impl<'items> CheckTreeItem<'items, String>
Sourcepub fn new_with_items<'a, 'text, Item, LeafFn>(
items: &'items [Item],
identifier: impl AsRef<str>,
text: impl Into<Text<'text>>,
leaf_fn: LeafFn,
) -> Result<Self, Error>
pub fn new_with_items<'a, 'text, Item, LeafFn>( items: &'items [Item], identifier: impl AsRef<str>, text: impl Into<Text<'text>>, leaf_fn: LeafFn, ) -> Result<Self, Error>
Create a CheckTreeState from a list of things
Errors
returns an error if the tree state cannot be created (e.g. duplicate ids)
Sourceimpl<'text, Identifier> CheckTreeItem<'text, Identifier>
impl<'text, Identifier> CheckTreeItem<'text, Identifier>
Sourcepub fn new_leaf<T>(identifier: Identifier, text: T) -> Self
pub fn new_leaf<T>(identifier: Identifier, text: T) -> Self
Create a new CheckTreeItem without children.
Sourcepub fn new<T>(
identifier: Identifier,
text: T,
children: Vec<Self>,
) -> Result<Self>
pub fn new<T>( identifier: Identifier, text: T, children: Vec<Self>, ) -> Result<Self>
Create a new CheckTreeItem with children.
Errors
Errors when there are duplicate identifiers in the children.
Sourcepub const fn identifier(&self) -> &Identifier
pub const fn identifier(&self) -> &Identifier
Get a reference to the identifier.
pub fn children(&self) -> &[Self]
Sourcepub fn child_mut(&mut self, index: usize) -> Option<&mut Self>
pub fn child_mut(&mut self, index: usize) -> Option<&mut Self>
Get a mutable reference to a child by index.
When you choose to change the identifier the CheckTreeState might not work as expected afterwards.
pub fn height(&self) -> usize