pub enum LibraryAction {
Show 13 variants
Rescan,
Update,
Analyze,
Recluster,
CreatePlaylist(String),
RemovePlaylist(RecordId),
RenamePlaylist(RecordId, String),
RemoveSongsFromPlaylist(RecordId, Vec<RecordId>),
AddThingsToPlaylist(RecordId, Vec<RecordId>),
CreatePlaylistAndAddThings(String, Vec<RecordId>),
CreateDynamicPlaylist(String, Query),
RemoveDynamicPlaylist(RecordId),
UpdateDynamicPlaylist(RecordId, DynamicPlaylistChangeSet),
}Variants
Rescan
Rescan the library
Update
Tell the Library Store to get the latest library data
Analyze
Analyze the library
Recluster
Recluster the collection
CreatePlaylist(String)
Create a new playlist with the given name
RemovePlaylist(RecordId)
Delete a playlist by id
RenamePlaylist(RecordId, String)
Rename a playlist by id
RemoveSongsFromPlaylist(RecordId, Vec<RecordId>)
Remove a song from a playlist (PlaylistId, Vec<SongId>)
AddThingsToPlaylist(RecordId, Vec<RecordId>)
Add a list of things to a playlist (PlaylistId, Vec<SongId>)
CreatePlaylistAndAddThings(String, Vec<RecordId>)
Create a new playlist with the given name (if it doesn’t exist) and add the songs to it
(PlaylistName, Vec<SongId>)
CreateDynamicPlaylist(String, Query)
Create a new dynamic playlist with the given name and query
RemoveDynamicPlaylist(RecordId)
Delete a dynamic playlist by id
UpdateDynamicPlaylist(RecordId, DynamicPlaylistChangeSet)
Update the query of a dynamic playlist