pub enum LibraryAction {
Rescan,
Update,
Analyze,
Recluster,
CreatePlaylist(String),
RemovePlaylist(Thing),
RemoveSongsFromPlaylist(Thing, Vec<Thing>),
AddThingsToPlaylist(Thing, Vec<Thing>),
CreatePlaylistAndAddThings(String, Vec<Thing>),
}Variants
Rescan
Rescan the library
Update
Tell the Library Store to get the latest library data
Analyze
Analyze the library
Recluster
Recluster the collection
CreatePlaylist(String)
Create a new playlist with the given name
RemovePlaylist(Thing)
Delete a playlist by id
RemoveSongsFromPlaylist(Thing, Vec<Thing>)
Remove a song from a playlist (PlaylistId, Vec<SongId>)
AddThingsToPlaylist(Thing, Vec<Thing>)
Add a list of things to a playlist (PlaylistId, Vec<SongId>)
CreatePlaylistAndAddThings(String, Vec<Thing>)
Create a new playlist with the given name (if it doesn’t exist) and add the songs to it
(PlaylistName, Vec<SongId>)