pub struct SearchState { /* private fields */ }Expand description
The audio state store.
Implementations
Sourceimpl SearchState
impl SearchState
Sourcepub fn new() -> (Self, UnboundedReceiver<SearchResult>)
pub fn new() -> (Self, UnboundedReceiver<SearchResult>)
create a new audio state store, and return the receiver for listening to state updates.
Sourcepub async fn main_loop(
&self,
daemon: Arc<MusicPlayerClient>,
action_rx: UnboundedReceiver<String>,
interrupt_rx: Receiver<Interrupted>,
) -> Result<Interrupted>
pub async fn main_loop( &self, daemon: Arc<MusicPlayerClient>, action_rx: UnboundedReceiver<String>, interrupt_rx: Receiver<Interrupted>, ) -> Result<Interrupted>
a loop that updates the audio state every tick.
Errors
Fails if the state cannot be sent or if the daemon client can’t connect to the server