pub struct Dispatcher { /* private fields */ }Expand description
an all-in-one dispactcher for managing state updates.
Implementations
Sourceimpl Dispatcher
impl Dispatcher
pub fn new() -> (Self, Receivers)
Sourcepub async fn main_loop(
&self,
daemon: Arc<MusicPlayerClient>,
terminator: Terminator,
action_rx: UnboundedReceiver<Action>,
interrupt_rx: Receiver<Interrupted>,
) -> Result<Interrupted>
pub async fn main_loop( &self, daemon: Arc<MusicPlayerClient>, terminator: Terminator, action_rx: UnboundedReceiver<Action>, interrupt_rx: Receiver<Interrupted>, ) -> Result<Interrupted>
the main loop for the dispatcher.
the dispatcher will run until the user exits the application.
Errors
if any of the state stores fail to run.