pub struct App {
pub action_tx: UnboundedSender<Action>,
/* private fields */
}Fields
action_tx: UnboundedSender<Action>Action Sender
Implementations
Sourceimpl App
impl App
Sourcepub fn move_with_search(self, state: &AppState) -> Self
pub fn move_with_search(self, state: &AppState) -> Self
Move the app with the given state, but only update components that need to be updated.
in this case, that is the search view
Sourcepub fn move_with_audio(self, state: &AppState) -> Self
pub fn move_with_audio(self, state: &AppState) -> Self
Move the app with the given state, but only update components that need to be updated.
in this case, that is the queuebar, and the control panel
Sourcepub fn move_with_library(self, state: &AppState) -> Self
pub fn move_with_library(self, state: &AppState) -> Self
Move the app with the given state, but only update components that need to be updated.
in this case, that is the content view
Sourcepub fn move_with_view(self, state: &AppState) -> Self
pub fn move_with_view(self, state: &AppState) -> Self
Move the app with the given state, but only update components that need to be updated.
in this case, that is the content view
Sourcepub fn move_with_component(self, state: &AppState) -> Self
pub fn move_with_component(self, state: &AppState) -> Self
Move the app with the given state, but only update components that need to be updated.
in this case, that is the active component
Sourcepub fn move_with_popup(self, popup: Option<Box<dyn Popup>>) -> Self
pub fn move_with_popup(self, popup: Option<Box<dyn Popup>>) -> Self
Move the app with the given state, but only update components that need to be updated.
in this case, that is the popup