pub struct QueryBuilder { /* private fields */ }Expand description
A Query Building interface for Dynamic Playlists
Currently just a wrapper around an InputBox,
but I want it to be more like a advanced search builder from something like airtable or a research database.
Implementations
Sourceimpl QueryBuilder
impl QueryBuilder
pub fn new(state: &AppState, action_tx: UnboundedSender<Action>) -> Self
pub fn text(&self) -> &str
pub fn handle_key_event(&mut self, key: KeyEvent)
pub fn handle_mouse_event(&mut self, mouse: MouseEvent, area: Rect)
pub fn reset(&mut self)