Struct UiManager

pub struct UiManager { /* private fields */ }

Implementations

Source

impl UiManager

pub const fn new(action_tx: UnboundedSender<Action>) -> Self

pub async fn main_loop( self, daemon: Arc<MusicPlayerClient>, state_rx: Receivers, interrupt_rx: Receiver<Interrupted>, ) -> Result<Interrupted>

Main loop for the UI manager.

This function will run until the user exits the application.

Errors

This function will return an error if there was an issue rendering to the terminal.