Struct CheckTreeState

pub struct CheckTreeState<Identifier> { /* private fields */ }
Keeps the state of what is currently selected and what was opened in a CheckTree

Implementations

Source

impl CheckTreeState<String>

pub fn get_checked_things(&self) -> Vec<RecordId>

Get the checked things from the tree state

pub fn get_selected_thing(&self) -> Option<RecordId>

Get the selected thing from the tree state

pub fn handle_mouse_event( &mut self, event: MouseEvent, area: Rect, ) -> Option<Action>

Handle mouse events interacting with the tree

Assumes that the given area only includes the CheckTree

Returns

an action if the mouse event requires it

Source

impl<Identifier> CheckTreeState<Identifier>
where Identifier: Clone + PartialEq + Eq + Hash,

pub const fn get_offset(&self) -> usize

pub const fn opened(&self) -> &HashSet<Vec<Identifier>>

pub fn selected(&self) -> &[Identifier]

Refers to the current cursor selection.

pub const fn checked(&self) -> &HashSet<Vec<Identifier>>

Refers to the current checked items.

pub fn flatten<'text>( &self, items: &'text [CheckTreeItem<'text, Identifier>], ) -> Vec<Flattened<'text, Identifier>>

Get a flat list of all currently viewable (including by scrolling) CheckTreeItems with this CheckTreeState.

pub fn select(&mut self, identifier: Vec<Identifier>) -> bool

Selects the given identifier.

Returns true when the selection changed.

Clear the selection by passing an empty identifier vector:

pub fn open(&mut self, identifier: Vec<Identifier>) -> bool

Open a tree node. Returns true when it was closed and has been opened. Returns false when it was already open.

TODO: This should return false when it was a leaf node.

pub fn close(&mut self, identifier: &[Identifier]) -> bool

Close a tree node. Returns true when it was open and has been closed. Returns false when it was already closed.

TODO: This should return false when it was a leaf node.

pub fn check(&mut self, identifier: Vec<Identifier>) -> bool

Check a tree node Returns true when it was unchecked and has been checked. Returns false when it was already checked.

TODO: This should return false when it was not a leaf node.

pub fn uncheck(&mut self, identifier: &[Identifier]) -> bool

Uncheck a tree node Returns true when it was checked and has been unchecked. Returns false when it was already unchecked.

TODO: This should return false when it was not a leaf node.

pub fn toggle(&mut self, identifier: Vec<Identifier>) -> bool

Toggles a tree node open/close state. When it is currently open, then close is called. Otherwise open.

Returns true when a node is opened / closed. As toggle always changes something, this only returns false when an empty identifier is given.

TODO: This should return false when it was a leaf node.

pub fn toggle_selected(&mut self) -> bool

Toggles the currently selected tree node open/close state. See also toggle

Returns true when a node is opened / closed. As toggle always changes something, this only returns false when nothing is selected.

TODO: This should return false when it was a leaf node.

pub fn toggle_check(&mut self, identifier: Vec<Identifier>) -> bool

Toggles a tree node checked/unchecked state. When it is currently checked, then uncheck is called. Otherwise check.

Returns true when a node is checked / unchecked. As toggle always changes something, this only returns false when an empty identifier is given.

TODO: This should return false when it was not a leaf node.

pub fn toggle_check_selected(&mut self) -> bool

Toggles the currently selected tree node checked/unchecked state. See also toggle_check Returns true when a node is checked / unchecked. As toggle always changes something, this only returns false when nothing is selected.

TODO: This should return false when it was not a leaf node.

pub fn reset(&mut self) -> bool

Closes all open nodes, and uncheck all checked nodes.

Returns true when any node was closed or unchecked.

pub fn select_first(&mut self) -> bool

Select the first node.

Returns true when the selection changed.

pub fn select_last(&mut self) -> bool

Select the last node.

Returns true when the selection changed.

pub fn select_relative<F>(&mut self, change_function: F) -> bool
where F: FnOnce(Option<usize>) -> usize,

Move the current selection with the direction/amount by the given function.

Returns true when the selection changed.

For more examples take a look into the source code of key_up or key_down. They are implemented with this method.

pub fn rendered_at(&self, position: Position) -> Option<&[Identifier]>

Get the identifier that was rendered for the given position on last render.

pub const fn scroll_selected_into_view(&mut self)

Ensure the selected CheckTreeItem is in view on next render

pub const fn scroll_up(&mut self, lines: usize) -> bool

Scroll the specified amount of lines up

Returns true when the scroll position changed. Returns false when the scrolling has reached the top.

pub fn scroll_down(&mut self, lines: usize) -> bool

Scroll the specified amount of lines down

Returns true when the scroll position changed. Returns false when the scrolling has reached the last CheckTreeItem.

pub fn key_up(&mut self) -> bool

Handles the up arrow key. Moves up in the current depth or to its parent.

Returns true when the selection changed.

pub fn key_down(&mut self) -> bool

Handles the down arrow key. Moves down in the current depth or into a child node.

Returns true when the selection changed.

pub fn key_left(&mut self) -> bool

Handles the left arrow key. Closes the currently selected or moves to its parent.

Returns true when the selection or the open state changed.

pub fn key_right(&mut self) -> bool

Handles the right arrow key. Opens the currently selected.

Returns true when it was closed and has been opened. Returns false when it was already open or nothing being selected.

pub fn key_space(&mut self) -> bool

Handles the space key. Toggles the whether the current item is selected

Returns true when the selection changed.

pub fn mouse_click(&mut self, position: Position) -> bool

Handles a mouse click. Selects the item at the given position. If the item is a leaf, it checks it. It the item is a branch, it toggles it open/closed.

Returns true when the selection or the open state changed. Returns false when nothing was rendered at the given position (nothing was clicked).