pub struct CheckTree<'a, Identifier> { /* private fields */ }Expand description
A CheckTree which can be rendered.
The generic argument Identifier is used to keep the state like the currently selected or opened CheckTreeItems in the CheckTreeState.
For more information see CheckTreeItem.
This differs from the tui_tree_widget crate’s Tree in that it allows for checkboxes to be rendered next to each leaf item.
This is useful for creating a tree of items that can be selected.
Implementations
Sourceimpl<'a, Identifier> CheckTree<'a, Identifier>
impl<'a, Identifier> CheckTree<'a, Identifier>
Sourcepub fn new(items: &'a [CheckTreeItem<'a, Identifier>]) -> Result<Self, Error>
pub fn new(items: &'a [CheckTreeItem<'a, Identifier>]) -> Result<Self, Error>
pub fn block(self, block: Block<'a>) -> Self
Sourcepub const fn experimental_scrollbar(
self,
scrollbar: Option<Scrollbar<'a>>,
) -> Self
pub const fn experimental_scrollbar( self, scrollbar: Option<Scrollbar<'a>>, ) -> Self
Show the scrollbar when rendering this widget.
Experimental: Can change on any release without any additional notice. Its there to test and experiment with whats possible with scrolling widgets. Also see https://github.com/ratatui-org/ratatui/issues/174
pub const fn style(self, style: Style) -> Self
pub const fn highlight_style(self, style: Style) -> Self
pub const fn highlight_symbol(self, highlight_symbol: &'a str) -> Self
pub const fn node_closed_symbol(self, symbol: &'a str) -> Self
pub const fn node_open_symbol(self, symbol: &'a str) -> Self
pub const fn node_checked_symbol(self, symbol: &'a str) -> Self
pub const fn node_unchecked_symbol(self, symbol: &'a str) -> Self